@@ -2,14 +2,14 @@ use std::collections::HashMap;
 use std::ffi::CString;
 use std::fmt::{Debug, Formatter};
 use std::marker::PhantomData;
+use std::ptr;
 use std::sync::Mutex;
 
 use libheif_sys as lh;
 
 use crate::utils::cstr_to_str;
 use crate::{
-    ChromaDownsamplingAlgorithm, ChromaUpsamplingAlgorithm, ColorConversionOptions, HeifError,
-    HeifErrorCode, HeifErrorSubCode, ImageOrientation, Result,
+    ColorConversionOptions, HeifError, HeifErrorCode, HeifErrorSubCode, ImageOrientation, Result,
 };
 
 static ENCODER_MUTEX: Mutex<()> = Mutex::new(());
@@ -38,6 +38,9 @@ pub enum CompressionFormat {
     Uncompressed = lh::heif_compression_format_heif_compression_uncompressed as _,
     /// Rust equivalent of [lh::heif_compression_format_heif_compression_mask]
     Mask = lh::heif_compression_format_heif_compression_mask as _,
+    /// Rust equivalent of [lh::heif_compression_format_heif_compression_HTJ2K]
+    #[cfg(feature = "v1_18")]
+    HtJ2k = lh::heif_compression_format_heif_compression_HTJ2K as _,
 }
 
 #[derive(Debug, Copy, Clone, PartialEq, Eq, Hash, enumn::N)]
@@ -229,20 +232,20 @@ fn parameters_types(c_encoder: &mut lh::heif_encoder) -> Result<EncoderParameter
 
 #[derive(Debug)]
 pub struct EncodingOptions {
-    pub(crate) inner: *mut lh::heif_encoding_options,
+    inner: ptr::NonNull<lh::heif_encoding_options>,
 }
 
 impl EncodingOptions {
     pub fn new() -> Result<Self> {
-        let inner = unsafe { lh::heif_encoding_options_alloc() };
-        if inner.is_null() {
-            return Err(HeifError {
+        let inner_ptr = unsafe { lh::heif_encoding_options_alloc() };
+        match ptr::NonNull::new(inner_ptr) {
+            Some(inner) => Ok(Self { inner }),
+            None => Err(HeifError {
                 code: HeifErrorCode::MemoryAllocationError,
                 sub_code: HeifErrorSubCode::Unspecified,
                 message: Default::default(),
-            });
+            }),
         }
-        Ok(Self { inner })
     }
 }
 
@@ -255,7 +258,7 @@ impl Default for EncodingOptions {
 impl Drop for EncodingOptions {
     fn drop(&mut self) {
         unsafe {
-            lh::heif_encoding_options_free(self.inner);
+            lh::heif_encoding_options_free(self.inner.as_ptr());
         }
     }
 }
@@ -263,12 +266,12 @@ impl Drop for EncodingOptions {
 impl EncodingOptions {
     #[inline(always)]
     fn inner_ref(&self) -> &lh::heif_encoding_options {
-        unsafe { &(*self.inner) }
+        unsafe { self.inner.as_ref() }
     }
 
     #[inline(always)]
     fn inner_mut(&mut self) -> &mut lh::heif_encoding_options {
-        unsafe { &mut (*self.inner) }
+        unsafe { self.inner.as_mut() }
     }
 
     #[inline]
@@ -335,31 +338,26 @@ impl EncodingOptions {
 
     pub fn color_conversion_options(&self) -> ColorConversionOptions {
         let lh_options = self.inner_ref().color_conversion_options;
-        ColorConversionOptions {
-            preferred_chroma_downsampling_algorithm: ChromaDownsamplingAlgorithm::n(
-                lh_options.preferred_chroma_downsampling_algorithm,
-            )
-            .unwrap_or(ChromaDownsamplingAlgorithm::Average),
-            preferred_chroma_upsampling_algorithm: ChromaUpsamplingAlgorithm::n(
-                lh_options.preferred_chroma_upsampling_algorithm,
-            )
-            .unwrap_or(ChromaUpsamplingAlgorithm::Bilinear),
-            only_use_preferred_chroma_algorithm: lh_options.only_use_preferred_chroma_algorithm
-                != 0,
-        }
+        ColorConversionOptions::from_cc_options(&lh_options)
     }
 
     pub fn set_color_conversion_options(&mut self, options: ColorConversionOptions) {
         let lh_options = &mut self.inner_mut().color_conversion_options;
-        lh_options.preferred_chroma_downsampling_algorithm =
-            options.preferred_chroma_downsampling_algorithm as _;
-        lh_options.preferred_chroma_upsampling_algorithm =
-            options.preferred_chroma_upsampling_algorithm as _;
-        lh_options.only_use_preferred_chroma_algorithm =
-            options.only_use_preferred_chroma_algorithm as _;
+        options.fill_cc_options(lh_options);
     }
 }
 
+/// This function makes sure the encoding options
+/// won't be freed too early.
+pub(crate) fn get_encoding_options_ptr(
+    options: &Option<EncodingOptions>,
+) -> *mut lh::heif_encoding_options {
+    options
+        .as_ref()
+        .map(|o| o.inner.as_ptr())
+        .unwrap_or_else(ptr::null_mut)
+}
+
 #[derive(Copy, Clone)]
 pub struct EncoderDescriptor<'a> {
     pub(crate) inner: &'a lh::heif_encoder_descriptor,
